@@ -150,6 +150,10 @@ static int have_network = 1;
 bool g_sleep = false;
     // simulate unresponsive app by setting to true (debugging)
 static FUNC_PTR timer_callback = 0;
+char web_graphics_url[256];
+bool send_web_graphics_url = false;
+char remote_desktop_addr[256];
+bool send_remote_desktop_addr = false;
 
 #define TIMER_PERIOD 0.1
     // period of worker-thread timer interrupts.
@@ -819,7 +823,7 @@ int suspend_activities() {
         }
     }
 #else
-    if (options.multi_process) {
+    if (options.multi_process && options.direct_process_action) {
         suspend_or_resume_descendants(0, false);
     }
 #endif
@@ -1126,7 +1130,7 @@ static void timer_handler() {
     fprintf(stderr, "%s 1 sec elapsed\n", boinc_msg_prefix(buf, sizeof(buf)));
 #endif
 
-    // here it we're at a one-second boundary; do slow stuff
+    // here if we're at a one-second boundary; do slow stuff
     //
 
     if (!ready_to_checkpoint) {
@@ -1178,6 +1182,25 @@ static void timer_handler() {
     if (timer_callback) {
         timer_callback();
     }
+
+    // send graphics-related messages
+    //
+    if (send_web_graphics_url && !app_client_shm->shm->graphics_reply.has_msg()) {
+        sprintf(buf,
+            "<web_graphics_url>%s</web_graphics_url>",
+            web_graphics_url
+        );
+        app_client_shm->shm->graphics_reply.send_msg(buf);
+        send_web_graphics_url = false;
+    }
+    if (send_remote_desktop_addr && !app_client_shm->shm->graphics_reply.has_msg()) {
+        sprintf(buf,
+            "<remote_desktop_addr>%s</remote_desktop_addr>",
+            remote_desktop_addr
+        );
+        app_client_shm->shm->graphics_reply.send_msg(buf);
+        send_remote_desktop_addr = false;
+    }
 }
 
 #ifdef _WIN32
@@ -1449,3 +1472,15 @@ double boinc_get_fraction_done() {
 double boinc_elapsed_time() {
     return running_interrupt_count*TIMER_PERIOD;
 }
+
+void boinc_web_graphics_url(char* url) {
+    if (standalone) return;
+    strcpy(web_graphics_url, url);
+    send_web_graphics_url = true;
+}
+
+void boinc_remote_desktop_addr(char* addr) {
+    if (standalone) return;
+    strcpy(remote_desktop_addr, addr);
+    send_remote_desktop_addr = true;
+}
