@@ -746,6 +746,12 @@ void RSS_FEED_OP::handle_reply(int http_op_retval) {
 
     rfp->feed_file_name(filename);
     FILE* f = fopen(filename, "r");
+    if (!f) {
+        msg_printf(0, MSG_INTERNAL_ERROR,
+            "RSS feed file '%s' not found", filename
+        );
+        return;
+    }
     MIOFILE fin;
     fin.init_file(f);
     XML_PARSER xp(&fin);
