@@ -75,8 +75,7 @@ static inline bool arrived_first(RESULT* r0, RESULT* r1) {
     if (r0->received_time > r1->received_time) {
         return false;
     }
-    return (strcmp(r0->name, r1->name) > 0);
-        // arbitrary but deterministic
+    return (r0 < r1);    // arbitrary but deterministic
 }
 
 // Parse the client_state.xml file
@@ -115,6 +114,7 @@ int CLIENT_STATE::parse_state_file_aux(const char* fname) {
     int retval=0;
     int failnum;
     bool btemp;
+    string stemp;
 
     FILE* f = fopen(fname, "r");
     if (!f) return ERR_FOPEN;
@@ -439,7 +439,7 @@ int CLIENT_STATE::parse_state_file_aux(const char* fname) {
         if (xp.parse_string("platform_name", statefile_platform_name)) {
             continue;
         }
-        if (xp.match_tag("alt_platform")) {
+        if (xp.parse_string("alt_platform", stemp)) {
             continue;
         }
         if (xp.parse_int("user_run_request", retval)) {
