@@ -25,7 +25,7 @@
 #include <ctime>
 #include <cmath>
 #include <cstring>
-#ifdef HAVE_SYS_SOCKET_H
+#if HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
 #endif
