@@ -209,7 +209,7 @@ public:
     ~APP_VERSION();
 
     int parse(XML_PARSER&);
-    int parse_coproc(MIOFILE&);
+    int parse_coproc(XML_PARSER&);
     void print();
     void clear();
 };
@@ -256,6 +256,7 @@ public:
     bool project_suspended_via_gui;
     bool coproc_missing;
     bool scheduler_wait;
+    bool network_wait;
 
     // the following defined if active
     bool active_task;
@@ -271,12 +272,12 @@ public:
     double working_set_size_smoothed;
     double estimated_cpu_time_remaining;
         // actually, estimated elapsed time remaining
-    bool supports_graphics;
-    int graphics_mode_acked;
     bool too_large;
     bool needs_shmem;
     bool edf_scheduled;
     char graphics_exec_path[512];
+    char web_graphics_url[256];
+    char remote_desktop_addr[256];
     char slot_path[512];
         // only present if graphics_exec_path is
     char resources[256];
